==> otu-5000-17.02.tar: usr/share/pydiag/eotdrv2/leds.py <==
from jdsu.evm import *
from jdsu.diag import *

LedsConfigurations = {
    "mts4000ng": {
        "ON":"on",
        "CHARGE_GREEN":"charge_green",
        "CHARGE_RED":"charge_red",
        "TESTING":"led_test",
        "HOME":"home",
        "APPS":"apps",
        "START":"start_stop",
        "UP":"arrow_up",
        "DOWN":"arrow_down",
        "RIGHT":"arrow_right",
        "LEFT":"arrow_left",
        "ENTER":"enter"
    },
    "mts2000ng": {
        "ON":"on",
        "CHARGE_GREEN":"charge_green",
        "CHARGE_RED":"charge_red",
        "TESTING":"led_test"
    },
    "mts1000": {
        "ON":"led_power",
        "CHARGE_GREEN":"led_ch_green",
        "CHARGE_ORANGE":"led_ch_orange",
        "TEST":"led_test",
        "PORT1":"led_13_15",
        "PORT2":"led_16"
    },
    "eotdrv2": {
        "TEST":"led_test",
        "SOFT_UPG":"led_soft_upg"
    }
}

@DIAG("Led test")
def t_led(cmd):
    with open("/proc/device-tree/model") as ifile:
        model = ifile.read().strip()
    conf = LedsConfigurations[model]

    try:
        (command,led,mode) = cmd.split()
    except:
        print_error("# Command must be: t_led <%s> <ON|OFF>"%("|".join(conf.keys())))
        return False

    if led not in conf.keys() or mode not in ("ON","OFF"):
        print_error("# Command must be: t_led <%s> <ON|OFF>"%("|".join(conf.keys())))
        return False
    if mode == "ON":
        sysfs_write("/sys/class/leds/%s/brightness" % conf[led], 1)
    else:
        sysfs_write("/sys/class/leds/%s/brightness" % conf[led], 0)
    return None

==> otu-5000-18.54.tar: usr/share/pydiag/eotdrv2/leds.py <==
from jdsu.evm import *
from jdsu.diag import *
import jdsu.mts as mts

LedsConfigurations = {
    "mts4000ng": {
        "ON":"on",
        "CHARGE_GREEN":"charge_green",
        "CHARGE_RED":"charge_red",
        "TESTING":"led_test",
        "HOME":"home",
        "APPS":"apps",
        "START":"start_stop",
        "UP":"arrow_up",
        "DOWN":"arrow_down",
        "RIGHT":"arrow_right",
        "LEFT":"arrow_left",
        "ENTER":"enter"
    },
    "mts2000ng": {
        "ON":"on",
        "CHARGE_GREEN":"charge_green",
        "CHARGE_RED":"charge_red",
        "TESTING":"led_test"
    },
    "mts1000": {
        "ON":"led_power",
        "CHARGE_GREEN":"led_ch_green",
        "CHARGE_ORANGE":"led_ch_orange",
        "TEST":"led_test",
        "PORT1":"led_13_15",
        "PORT2":"led_16"
    },
    "eotdrv2": {
        "TEST":"led_test",
        "SOFT_UPG":"led_soft_upg"
    }
}

@DIAG("Led test")
def t_led(cmd):
    conf = LedsConfigurations[mts.getMachineName()]
    try:
        (command,led,mode) = cmd.split()
    except:
        print_error("# Command must be: t_led <%s> <ON|OFF>"%("|".join(conf.keys())))
        return False

    if led not in conf.keys() or mode not in ("ON","OFF"):
        print_error("# Command must be: t_led <%s> <ON|OFF>"%("|".join(conf.keys())))
        return False
    if mode == "ON":
        sysfs_write("/sys/class/leds/%s/brightness" % conf[led], 1)
    else:
        sysfs_write("/sys/class/leds/%s/brightness" % conf[led], 0)
    return None
